@@ -37,7 +37,6 @@ public:
     T result() const;
 
 private:
-    ItemJob(const QSharedPointer<PlatformDependent>& internals, const QNetworkRequest& request);
     ItemJob(PlatformDependent*, const QNetworkRequest& request);
     virtual void parse(const QString& xml);
     T m_item;
@@ -52,8 +51,6 @@ public:
     T result() const;
 
 private:
-    ItemPostJob(const QSharedPointer<PlatformDependent>& internals, const QNetworkRequest& request, QIODevice * data);
-    ItemPostJob(const QSharedPointer<PlatformDependent>& internals, const QNetworkRequest& request, const StringMap& parameters = StringMap());
     ItemPostJob(PlatformDependent* internals, const QNetworkRequest& request, QIODevice * data);
     ItemPostJob(PlatformDependent* internals, const QNetworkRequest& request, const StringMap& parameters = StringMap());
 
