@@ -29,7 +29,6 @@
 #include <QtCore/QPluginLoader>
 #include <QtCore/QSet>
 #include <QtCore/QSignalMapper>
-#include <QtCore/QSharedPointer>
 #include <QtCore/QTimer>
 #include <QtCore/QProcess>
 #include <QtNetwork/QAuthenticator>
@@ -125,7 +124,8 @@ void ProviderManager::setAuthenticationSuppressed(bool suppressed)
     d->m_authenticationSuppressed = suppressed;
 }
 
-void ProviderManager::clear() {
+void ProviderManager::clear()
+{
     d->m_providerFiles.clear();
     d->m_providers.clear();
 }
@@ -140,11 +140,27 @@ void ProviderManager::slotLoadDefaultProvidersInternal()
     }
 }
 
+QList<QUrl> ProviderManager::defaultProviderFiles()
+{
+    return d->m_internals->getDefaultProviderFiles();
+}
+
 ProviderManager::~ProviderManager()
 {
     delete d;
 }
 
+void ProviderManager::addProviderFileToDefaultProviders(const QUrl& url)
+{
+    d->m_internals->addDefaultProviderFile(url);
+    addProviderFile(url);
+}
+
+void ProviderManager::removeProviderFileFromDefaultProviders(const QUrl& url)
+{
+    d->m_internals->removeDefaultProviderFile(url);
+}
+
 void ProviderManager::addProviderFile(const QUrl& url)
 {
     QString localFile = url.toLocalFile();
@@ -185,17 +201,43 @@ void ProviderManager::parseProviderFile(const QString& xmlString, const QString&
             QString baseUrl;
             QString name;
             QUrl icon;
+            QString person;
+            QString friendV;
+            QString message;
+            QString activity;
+            QString content;
+            QString fan;
+            QString knowledgebase;
+            QString event;
+            QString comment;
+            
             while (!xml.atEnd() && xml.readNext()) {
                 if (xml.isStartElement())
                 {
                     if (xml.name() == "location") {
                         baseUrl = xml.readElementText();
-                    }
-                    if (xml.name() == "name") {
+                    } else if (xml.name() == "name") {
                         name = xml.readElementText();
-                    }
-                    if (xml.name() == "icon") {
+                    } else if (xml.name() == "icon") {
                         icon = QUrl(xml.readElementText());
+                    } else if (xml.name() == "person") {
+                        person = xml.attributes().value("ocsversion").toString();
+                    } else if (xml.name() == "friend") {
+                        friendV = xml.attributes().value("ocsversion").toString();
+                    } else if (xml.name() == "message") {
+                        message = xml.attributes().value("ocsversion").toString();
+                    } else if (xml.name() == "activity") {
+                        activity = xml.attributes().value("ocsversion").toString();
+                    } else if (xml.name() == "content") {
+                        content = xml.attributes().value("ocsversion").toString();
+                    } else if (xml.name() == "fan") {
+                        fan = xml.attributes().value("ocsversion").toString();
+                    } else if (xml.name() == "knowledgebase") {
+                        knowledgebase = xml.attributes().value("ocsversion").toString();
+                    } else if (xml.name() == "event") {
+                        event = xml.attributes().value("ocsversion").toString();
+                    } else if (xml.name() == "comment") {
+                        comment = xml.attributes().value("ocsversion").toString();
                     }
                 } else if (xml.isEndElement() && xml.name() == "provider") {
                     break;
@@ -203,7 +245,8 @@ void ProviderManager::parseProviderFile(const QString& xmlString, const QString&
             }
             if (!baseUrl.isEmpty()) {
                 qDebug() << "Adding provider" << baseUrl;
-                d->m_providers.insert(baseUrl, Provider(d->m_internals, QUrl(baseUrl), name, icon));
+                d->m_providers.insert(baseUrl, Provider(d->m_internals, QUrl(baseUrl), name, icon,
+                    person, friendV, message, activity, content, fan, knowledgebase, event, comment));
                 emit providerAdded(d->m_providers.value(baseUrl));
             }
         }
