@@ -24,10 +24,36 @@
 #include "qtplatformdependent.h"
 
 #include <QtCore/QUrl>
-
+#include <QtCore/QStringList>
+#include <QtCore/QDebug>
 
 using namespace Attica;
 
+// TODO actually save and restore providers!
+QList<QUrl> Attica::QtPlatformDependent::getDefaultProviderFiles() const
+{
+    return QList<QUrl>();
+}
+
+void QtPlatformDependent::addDefaultProviderFile(const QUrl&)
+{
+    qDebug() << "attica-qt does not support default providers yet";
+}
+
+void QtPlatformDependent::removeDefaultProviderFile(const QUrl&)
+{
+}
+
+void QtPlatformDependent::enableProvider(const QUrl& baseUrl, bool enabled) const
+{
+    qDebug() << "attica-qt does not support disabling of providers yet";
+}
+
+bool QtPlatformDependent::isEnabled(const QUrl& baseUrl) const
+{
+    return true;
+}
+
 QNetworkReply* QtPlatformDependent::post(const QNetworkRequest& request, const QByteArray& data)
 {
     return m_qnam.post(request, data);
@@ -75,12 +101,6 @@ bool Attica::QtPlatformDependent::askForCredentials(const QUrl& baseUrl, QString
     return false;
 }
 
-QList<QUrl> Attica::QtPlatformDependent::getDefaultProviderFiles() const
-{
-    return QList<QUrl>();
-}
-
-
 QNetworkAccessManager* Attica::QtPlatformDependent::nam()
 {
     return &m_qnam;
